/******************************************************************************
 * AVR32 AP7000 GNU ld script file.
 *
 * This script allows to link code to FLASH without Newlib support.
 *
 * - Compiler:           GNU GCC for AVR32
 * - Supported devices:  AVR32 AP7000
 *
 * - author              Atmel Corporation: http://www.atmel.com \n
 *                       Support email: avr32@atmel.com
 *
 ******************************************************************************/

/* Copyright (c) 2007, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


OUTPUT_FORMAT(elf32-avr32)
ENTRY(_start) 

/* Misc definitions */
__gcc_stack_size      = 1K;

SECTIONS
{
  . = 0x00020000;
  __reset_start__ = .;
  __reset = .;
  .reset : AT(0x00020000) {
          *(.reset);
  }
  __reset_end__ = .;

  __exit_start__ = .;
  .exit : {
          *(.exit*);
  }
  __exit_end__ = .;

  __evba_start__ = .;
  .exception : {
          *(.exception*);
  }
  __evba_end__ = .;

  . = ALIGN(4);
  __text_start__ = .;
  .text : {
          *(.text*);
          *(.rodata*);
  }
  __text_end__ = ALIGN(4);

  . = 0x24000000; /* Start of internal RAM */
  __idata_start__ =  __text_end__; /* Load memory address of initialized data with a global lifetime */
  __data_start__ = .;             /* Virtual memory address of initialized data with a global lifetime */
  .data :  AT (__idata_start__) {
          *(.data*)
  } = 0x0
  __data_end__ = ALIGN(8);
  __idata_end__ = __idata_start__ + __data_end__ - __data_start__;

  . = ALIGN(8);
  __bss_start__ = .;
  .bss : {
          *(.bss*)
  } = 0x0
  __bss_end__ = ALIGN(8);

  . = ALIGN(4);
  __stack_start__ = .;
  . = __stack_start__ + __gcc_stack_size;
  __stack         = .;
  __stack_end__   = ALIGN(4);
}
